@@ -5,6 +5,7 @@
 import logging
 import os.path
 import re
+import sys
 from pathlib import PurePath
 from subprocess import PIPE, Popen
 
@@ -42,6 +43,7 @@ def pylsp_lint(workspace, document):
         'hang-closing': settings.get('hangClosing'),
         'ignore': ignores or None,
         'max-line-length': settings.get('maxLineLength'),
+        'indent-size': settings.get('indentSize'),
         'select': settings.get('select'),
     }
 
@@ -81,8 +83,8 @@ def run_flake8(flake8_executable, args, document):
         cmd.extend(args)
         p = Popen(cmd, stdin=PIPE, stdout=PIPE, stderr=PIPE)
     except IOError:
-        log.debug("Can't execute %s. Trying with 'python -m flake8'", flake8_executable)
-        cmd = ['python', '-m', 'flake8']
+        log.debug("Can't execute %s. Trying with '%s -m flake8'", flake8_executable, sys.executable)
+        cmd = [sys.executable, '-m', 'flake8']
         cmd.extend(args)
         p = Popen(cmd, stdin=PIPE, stdout=PIPE, stderr=PIPE)  # pylint: disable=consider-using-with
     (stdout, stderr) = p.communicate(document.source.encode())
